@@ -1,5 +1,24 @@
 BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 
+.repositories_check_repos_envopt <-
+    function()
+{
+    opt <- Sys.getenv("BIOCMANAGER_CHECK_REPOSITORIES", TRUE)
+    opt <- getOption("BiocManager.check_repositories", opt)
+    isTRUE(as.logical(opt))
+}
+
+.repositories_site_repository <-
+    function()
+{
+    opt <- Sys.getenv("BIOCMANAGER_SITE_REPOSITORY", "")
+    opt <- getOption("BiocManager.site_repository", opt)
+    if (!nzchar(opt))
+        character()
+    else
+        opt
+}
+
 .repositories_check_repos <-
     function(repos)
 {
@@ -8,92 +27,44 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
     conflict <- conflict & repos != "@CRAN@"
     conflicts <- repos[conflict]
 
-    ## FIXME: allow for MRAN repositories from appropriate dates for
-    ## BiocManager::version()
-    ##
-    ## pattern <-
-    ##     "snapshot/(20[[:digit:]]{2}-[[:digit:]]{2}-[[:digit:]]{2})/*$"
-    ## is_snapshot <- grepl(pattern, repos)
-    ## if (any(is_snapshot)) {
-    ##     ...
-    ## }
-
     if (length(conflicts)) {
         txt <- paste(
             "'getOption(\"repos\")' replaces Bioconductor standard ",
-            "repositories, see '?repositories' for details"
+            "repositories, see ",
+            "'help(\"repositories\", package = \"BiocManager\")' for details."
         )
         fmt <- paste0(
             .msg(txt, exdent = 0),
-            "\n\nreplacement repositories:",
+            "\nReplacement repositories:",
             "\n    %s\n"
         )
         repos_string <- paste0(
             names(conflicts), ": ", unname(conflicts),
             collapse = "\n    "
         )
-        if (getOption("BiocManager.check_repositories", TRUE))
-            .message(fmt, repos_string, call. = FALSE, wrap. = FALSE)
+        if (.repositories_check_repos_envopt())
+            .message(
+                fmt, repos_string,
+                call. = FALSE, wrap. = FALSE, appendLF = FALSE
+            )
     }
 
     repos
 }
 
-.repositories_rspm <-
-    function(cran)
-{
-    rspm_version <- .version_field("RSPM")
-    if (is.na(rspm_version)) {
-        cran
-    } else {
-        rspm_version <- format(as.Date(rspm_version, "%m/%d/%Y"), "%Y-%m-%d")
-        paste0("https://packagemanager.rstudio.com/cran/", rspm_version)
-    }
-}
-
-.repositories_mran <-
-    function(cran)
-{
-    mran_version <- .version_field("MRAN")
-    if (is.na(mran_version)) {
-        cran
-    } else {
-        mran_version <- format(as.Date(mran_version, "%m/%d/%Y"), "%Y-%m-%d")
-        paste0("https://mran.microsoft.com/snapshot/", mran_version)
-    }
-}
-
 .repositories_base <-
     function()
 {
     repos <- getOption("repos")
     repos <- .repositories_check_repos(repos)
     rename <- repos == "@CRAN@"
-    if (any(rename)) {
-        ## default <- if (version() > "3.11") "MRAN" else "CRAN"
-        opt <- getOption("BiocManager.snapshot", "CRAN")
-        valid <- c("CRAN", "MRAN", "RSPM")
-        if (length(opt) != 1L || !opt %in% valid)
-            .stop(
-                "'getOption(\"BiocManager.snapshot\")' must be one of %s",
-                paste0("'", valid, "'", collapse = " ")
-            )
-        cran <- "https://cloud.r-project.org"
-        repos[rename] <- switch(
-            opt,
-            RSPM = .repositories_rspm(cran),
-            MRAN = .repositories_mran(cran),
-            CRAN = cran,
-            .stop("unknown option 'BiocManager.snapshot = \"%s\"'", opt)
-        )
-    }
-
+    repos[rename] <- "https://cloud.r-project.org"
     repos
 }
 
 #' @importFrom stats setNames
 .repositories_bioc <-
-    function(version)
+    function(version, ..., type = NULL)
 {
     mirror <- getOption("BioC_mirror", "https://bioconductor.org")
     paths <- c(
@@ -105,7 +76,7 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
     )
     bioc_repos <- paste(mirror, "packages", version, paths, sep="/")
     c(
-        containerRepository(version = version),
+        containerRepository(version = version, type = type),
         setNames(bioc_repos, names(paths))
     )
 }
@@ -126,10 +97,10 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 }
 
 .repositories <-
-    function(site_repository, version)
+    function(site_repository, version, ...)
 {
     base <- .repositories_base()
-    bioc <- .repositories_bioc(version)
+    bioc <- .repositories_bioc(version, ...)
 
     repos <- c(site_repository = site_repository, bioc, base)
     repos[!duplicated(names(repos))]
@@ -137,7 +108,7 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 
 #' @title Display current Bioconductor and CRAN repositories.
 #'
-#' @aliases BiocManager.snapshot BiocManager.check_repositories
+#' @aliases BiocManager.check_repositories
 #'
 #' @description `repositories()` reports the URLs from which to
 #'     install _Bioconductor_ and CRAN packages. It is used by
@@ -153,6 +124,14 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 #'     indicating the _Bioconductor_ version (e.g., "3.8") for which
 #'     repositories are required.
 #'
+#' @param ... Additional parameters passed to lower level functions, not
+#'   used.
+#'
+#' @param type (Optional) `character(1)` indicating the type of package
+#'   repository to retrieve (default: "both"). Setting `type` to "source" will
+#'   disable any Bioconductor binary packages specifically built for the
+#'   containers.
+#'
 #' @details
 #'
 #' `repositories()` returns the appropriate software package
@@ -164,33 +143,6 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 #' best practice is to use packages from the same release, and from
 #' the appropriate CRAN repository.
 #'
-#' CRAN packages for out-of-date _Bioconductor_ installations can be
-#' installed from historical 'snapshots' consistent with the last date
-#' the Bioconductor version was current.  This behavior can be specified with
-#' `BiocManager.snapshot` For example, _Bioconductor_ version 3.11 was current
-#' until October 28, 2020; CRAN packages are therefore installed from
-#' a snapshot created on 2020-10-28. By default, the snapshots are
-#' from 'MRAN', the [Microsoft R Archive Network][MRAN]. Use
-#' `options(BiocManager.snapshot = "RSPM")` to instead use the
-#' [RStudio Package Manager][RSPM], or `options(BiocManager.snapshot =
-#' "CRAN")` to use the current CRAN repository (i.e., disabling the
-#' snapshot feature).
-#'
-#' [MRAN]: https://mran.microsoft.com/timemachine
-#' [RSPM]: https://packagemanager.rstudio.com/client/#/repos/2/overview
-#'
-#' It may be desirable to specify different default repositories,
-#' especially CRAN, for intentionally out-of-date _Bioconductor_
-#' releases (e.g., to support reproducible research). Use the approach
-#' provided by base _R_ to specify alternative repositories, e.g.,
-#' `options(repos = c(CRAN =
-#' "https://mran.microsoft.com/snapshot/2020-02-08"))`. This is
-#' supported, but generates an error because specification of an
-#' inappropriate CRAN repository (one providing packages not
-#' consistent with the dates of the _Bioconductor_ release) results in
-#' use of CRAN packages not consistent with _Bioconductor_ best
-#' practices.
-#'
 #' To install binary packages on containerized versions of Bioconductor,
 #' a default binary package location URL is set as a package constant,
 #' see `BiocManager:::BINARY_BASE_URL`. Binary package installations
@@ -202,12 +154,13 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 #' `bioconductor/bioconductor_docker` images where such installations
 #' correspond to specific versions of Linux / Ubuntu.
 #'
-#' If alternative default repositories are known to provide
-#' appropriate versions of CRAN or _Bioconductor_ packages, the warning
-#' may be silenced (displayed as a message) with
-#' `options(BiocManager.check_repositories = FALSE)`. A message is
-#' still printed, to serve as a reminder when debugging problems
-#' related to incompatible package installation.
+#' If alternative default repositories are known to provide appropriate
+#' versions of CRAN or _Bioconductor_ packages, the message may be silenced
+#' by setting either the option or the variable to `FALSE`, i.e.,
+#' `options(BiocManager.check_repositories = FALSE)` or
+#' \env{BIOCMANAGER_CHECK_REPOSITORIES=FALSE}. Alternative default
+#' repositories are not guaranteed to work without issues related to
+#' incompatible package installations and are used at the user's own risk.
 #'
 #' The intended use of `site_repository =` is to enable installation of
 #' packages not available in the default repositories, e.g., packages
@@ -217,6 +170,9 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 #' that _R_'s standard rules of package selection apply, so the most
 #' recent version of candidate packages is selected independent of the
 #' location of the repository in the vector returned by `repositories()`.
+#' To set a more permenanent `site_repository`, one can use either the
+#' \env{BIOCMANAGER_SITE_REPOSITORY} environment variable or the
+#' `options(BiocManager.site_repository = ...)` option.
 #'
 #' For greater flexiblity in installing packages while still adhering
 #' as much as possible to _Bioconductor_ best practices, use
@@ -227,16 +183,16 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 #'
 #' @seealso
 #'
-#' `BiocManager::\link{install}()` Installs or updates Bioconductor,
+#' \code{BiocManager::\link{install}()} Installs or updates Bioconductor,
 #'  CRAN, and GitHub packages.
 #'
-#' `\link{chooseBioCmirror}()` choose an alternative Bioconductor
+#' \code{\link{chooseBioCmirror}()} choose an alternative Bioconductor
 #' mirror; not usually necessary.
 #'
-#' `\link{chooseCRANmirror}()` choose an alternative CRAN mirror; not
+#' \code{\link{chooseCRANmirror}()} choose an alternative CRAN mirror; not
 #' usually necessary.
 #'
-#' `\link{setRepositories}()` Select additional repositories for
+#' \code{\link{setRepositories}()} Select additional repositories for
 #' searching.
 #'
 #' @keywords environment
@@ -249,15 +205,21 @@ BINARY_BASE_URL <- "https://bioconductor.org/packages/%s/container-binaries/%s"
 #'
 #' @md
 #' @export repositories
-repositories <-
-    function(site_repository = character(), version = BiocManager::version())
-{
+repositories <- function(
+    site_repository = character(),
+    version = BiocManager::version(),
+    ...,
+    type = "both"
+) {
+    if (!length(site_repository) || !nzchar(site_repository))
+        site_repository <- .repositories_site_repository()
+
     stopifnot(
         length(site_repository) <= 1L,
         is.character(site_repository), !anyNA(site_repository)
     )
     version <- .version_validate(version)
-    .repositories(site_repository, version)
+    .repositories(site_repository, version, ..., type = type)
 }
 
 ## is the docker container configured correctly?
@@ -324,9 +286,11 @@ repositories <-
 #' @export
 containerRepository <-
     function(
-        version = BiocManager::version()
+        version = BiocManager::version(), type = "binary"
     )
 {
+    if (identical(type, "source"))
+        return(character())
     platform_docker <- .repository_container_version()
     container_version <- platform_docker$container_version
     platform <- platform_docker$platform
