@@ -56,35 +56,35 @@
 #' nor too new) with the version of R and _Bioconductor_ in use.
 #'
 #' @details This function compares the version of installed packages
-#'     to the version of packages associated with the version of _R_
-#'     and _Bioconductor_ currently in use.
+#'   to the version of packages associated with the version of _R_
+#'   and _Bioconductor_ currently in use.
 #'
-#'     Packages are reported as 'out-of-date' if a more recent version
-#'     is available at the repositories specified by
-#'     `BiocManager::repositories()`.  Usually, `BiocManager::install()` is
-#'     sufficient to update packages to their most recent version.
+#'   Packages are reported as 'out-of-date' if a more recent version
+#'   is available at the repositories specified by
+#'   `BiocManager::repositories()`.  Usually, `BiocManager::install()` is
+#'   sufficient to update packages to their most recent version.
 #'
-#'     Packages are reported as 'too new' if the installed version is
-#'     more recent than the most recent available in the
-#'     `BiocManager::repositories()`. It is possible to down-grade by
-#'     re-installing a too new package "PkgA" with
-#'     `BiocManger::install("PkgA")`. It is important for the user to
-#'     understand how their installation became too new, and to avoid
-#'     this in the future.
+#'   Packages are reported as 'too new' if the installed version is
+#'   more recent than the most recent available in the
+#'   `BiocManager::repositories()`. It is possible to down-grade by
+#'   re-installing a too new package "PkgA" with
+#'   `BiocManger::install("PkgA")`. It is important for the user to
+#'   understand how their installation became too new, and to avoid
+#'   this in the future.
 #'
 #' @param pkgs A character() vector of package names for checking, or
-#'     a matrix as returned by `\link{installed.packages}`.
+#'     a matrix as returned by \code{\link{installed.packages}()}`.
 #' @param lib.loc A character() vector of library location(s) of
-#'     packages to be validated; see `\link{installed.packages}()`.
+#'     packages to be validated; see \code{\link{installed.packages}()}.
 #' @param priority character(1) Check validity of all, "base", or
-#'     "recommended" packages; see `\link{installed.packages}()`.
+#'     "recommended" packages; see \code{\link{installed.packages}()}.
 #' @param type character(1) The type of available package (e.g.,
 #'     binary, source) to check validity against; see
-#'     `\link{available.packages}()`.
+#'     \code{\link{available.packages}()}.
 #' @param filters character(1) Filter available packages to check
-#'     validity against; see `\link{available.packages}()`.
+#'     validity against; see \code{\link{available.packages}()}.
 #' @param \dots Additional arguments, passed to
-#'     `BiocManager::\link{install}()` when `fix=TRUE`.
+#'     \code{BiocManager::\link{install}()} when `fix=TRUE`.
 #' @param checkBuilt `logical(1)`. If `TRUE` a package built under an
 #'     earlier major.minor version of R (e.g., 3.4) is considered to
 #'     be old.
@@ -96,11 +96,13 @@
 #'     is unavailable, an empty 'biocValid' list is returned. If all
 #'     packages ('pkgs') are up to date, then TRUE is returned.
 #' @author Martin Morgan \email{martin.morgan@@roswellpark.org}
-#' @seealso `BiocManager::\link{install}()` to update installed
+#' @seealso \code{BiocManager::\link{install}()} to update installed
 #'     packages.
 #' @keywords environment
 #' @examples
-#' BiocManager::valid()
+#' if (interactive()) {
+#'   BiocManager::valid()
+#' }
 #' @md
 #' @export valid
 valid <-
@@ -170,7 +172,7 @@ print.biocValid <-
         return()
     }
 
-    fmt <-'  BiocManager::install(%s, update = TRUE, ask = FALSE)'
+    fmt <-'  BiocManager::install(%s, update = TRUE, ask = FALSE, force = TRUE)'
     if (n == 1L) {
         fmt <- sprintf(fmt, '"%s"')
     } else {
